==> assertive_0.3-1.tar.gz: assertive/R/exports-base.R <==
# From assertive.base are-identical.R assert-are-identical.R

#' Are the inputs identical?
#' 
#' See \code{\link[assertive.base]{are_identical}}.
#' @name are_identical
#' @aliases assert_are_identical are_identical_legacy assert_all_are_identical_legacy assert_any_are_identical_legacy
#' @export are_identical
#' @export assert_are_identical
#' @export are_identical_legacy
#' @export assert_all_are_identical_legacy
#' @export assert_any_are_identical_legacy
NULL 

# From assertive.base assert-is-identical-to-true-false-na.R, 
# assert-is-true-false-na.R, is-identical-to-true-false-na.R,
# is-true-false-na.R

#' Is the input TRUE/FALSE/NA?
#' 
#' See \code{\link[assertive.base]{Truth}}.
#' @name Truth
#' @aliases assert_all_are_false assert_any_are_false is_false assert_all_are_na  assert_any_are_na is_na assert_all_are_true assert_any_are_true is_true assert_all_are_not_false  assert_any_are_not_false is_not_false assert_all_are_not_na  assert_any_are_not_na is_not_na assert_all_are_not_true assert_any_are_not_true is_not_true assert_is_identical_to_false is_identical_to_false assert_is_identical_to_na is_identical_to_na assert_is_identical_to_true is_identical_to_true
#' @export assert_all_are_false 
#' @export assert_any_are_false
#' @export is_false
#' @export assert_all_are_na 
#' @export assert_any_are_na
#' @export is_na
#' @export assert_all_are_true
#' @export assert_any_are_true
#' @export is_true
#' @export assert_all_are_not_false 
#' @export assert_any_are_not_false
#' @export is_not_false
#' @export assert_all_are_not_na 
#' @export assert_any_are_not_na
#' @export is_not_na
#' @export assert_all_are_not_true
#' @export assert_any_are_not_true
#' @export is_not_true
#' @export assert_is_identical_to_false
#' @export is_identical_to_false
#' @export assert_is_identical_to_na
#' @export is_identical_to_na
#' @export assert_is_identical_to_true
#' @export is_identical_to_true
NULL

# From assertive.base cause.R

#' Get or set the \code{"cause"} attribute
#' 
#' See \code{\link[assertive.base]{cause}}.
#' @name cause
#' @aliases cause<-
#' @export cause
#' @export cause<-
NULL

#' Set a cause and return the input
#' 
#' See \code{\link[assertive.base]{set_cause}}.
#' @name set_cause
#' @export
NULL

# From assertive.base coercion.R

#' Alternative version of is
#' 
#' See \code{\link[assertive.base]{is2}}.
#' @name is2
#' @export
NULL

#' Coerce variable to a different class
#' 
#' See \code{\link[assertive.base]{coerce_to}}.
#' @name coerce_to
#' @export
NULL

# From assertive.base conditions.R

#' Condition classes
#' 
#' See \code{\link[assertive.base]{assertionError}}.
#' @name assertionError
#' @aliases assertionWarning assertionMessage
#' @export assertionError
#' @export assertionWarning
#' @export assertionMessage
NULL

# From assertive.base engine.R

#' Throws an error if a condition isn't met
#' 
#' See \code{\link[assertive.base]{assert_engine}}.
#' @name assert_engine
#' @export
NULL

#' FALSE, with a cause of failure
#' 
#' See \code{\link[assertive.base]{false}}.
#' @name false
#' @export
NULL

#' NA, with a cause of failure
#' 
#' See \code{\link[assertive.base]{na}}.
#' @name na
#' @export
NULL

# From assertive.base utils.R

#' Wrapper to vapply that returns booleans.
#' 
#' See \code{\link[assertive.base]{bapply}}.
#' @name bapply
#' @export
NULL

#' Call a function, and give the result names.
#' 
#' See \code{\link[assertive.base]{call_and_name}}.
#' @name call_and_name
#' @export
NULL

#' Get the dimensions of an object
#' 
#' See \code{\link[assertive.properties]{DIM}}.
#' @name DIM
#' @export
NULL

#' Run code without stopping
#' 
#' See \code{\link[assertive.base]{dont_stop}}.
#' @name dont_stop
#' @export
NULL

#' Get the name of a variable in the parent frame
#' 
#' See \code{\link[assertive.base]{get_name_in_parent}}.
#' @name get_name_in_parent
#' @export
NULL

#' Merge ellipsis args with a list.
#' 
#' See \code{\link[assertive.base]{merge_dots_with_list}}.
#' @name merge_dots_with_list
#' @export
NULL

#' Get the number of elements
#' 
#' See \code{\link[assertive.properties]{n_elements}}.
#' @name n_elements
#' @export
NULL

#' Wrap a string in brackets
#' 
#' See \code{\link[assertive.base]{parenthesize}}.
#' @name parenthesize
#' @aliases parenthesise
#' @export parenthesize
#' @export parenthesise
NULL

#' Strip all attributes from a variable
#' 
#' See \code{\link[assertive.base]{strip_attributes}}.
#' @name strip_attributes
#' @export
NULL

#' Only use the first element of a vector
#' 
#' See \code{\link[assertive.base]{use_first}}.
#' @name use_first
#' @export
NULL

==> assertive_0.3-6.tar.gz: assertive/R/exports-base.R <==
# From assertive.base are-identical.R assert-are-identical.R

#' Are the inputs identical?
#' 
#' See \code{\link[assertive.base]{are_identical}}.
#' @name are_identical
#' @aliases assert_are_identical are_identical_legacy assert_all_are_identical_legacy assert_any_are_identical_legacy
#' @export are_identical
#' @export assert_are_identical
#' @export are_identical_legacy
#' @export assert_all_are_identical_legacy
#' @export assert_any_are_identical_legacy
NULL 

# From assertive.base assert-is-identical-to-true-false-na.R, 
# assert-is-true-false-na.R, is-identical-to-true-false-na.R,
# is-true-false-na.R

#' Is the input TRUE/FALSE/NA?
#' 
#' See \code{\link[assertive.base]{Truth}}.
#' @name Truth
#' @aliases assert_all_are_false assert_any_are_false is_false assert_all_are_na  assert_any_are_na is_na assert_all_are_true assert_any_are_true is_true assert_all_are_not_false  assert_any_are_not_false is_not_false assert_all_are_not_na  assert_any_are_not_na is_not_na assert_all_are_not_true assert_any_are_not_true is_not_true assert_is_identical_to_false is_identical_to_false assert_is_identical_to_na is_identical_to_na assert_is_identical_to_true is_identical_to_true
#' @export assert_all_are_false 
#' @export assert_any_are_false
#' @export is_false
#' @export assert_all_are_na 
#' @export assert_any_are_na
#' @export is_na
#' @export assert_all_are_true
#' @export assert_any_are_true
#' @export is_true
#' @export assert_all_are_not_false 
#' @export assert_any_are_not_false
#' @export is_not_false
#' @export assert_all_are_not_na 
#' @export assert_any_are_not_na
#' @export is_not_na
#' @export assert_all_are_not_true
#' @export assert_any_are_not_true
#' @export is_not_true
#' @export assert_is_identical_to_false
#' @export is_identical_to_false
#' @export assert_is_identical_to_na
#' @export is_identical_to_na
#' @export assert_is_identical_to_true
#' @export is_identical_to_true
NULL

# From assertive.base cause.R

#' Get or set the \code{"cause"} attribute
#' 
#' See \code{\link[assertive.base]{cause}}.
#' @name cause
#' @aliases cause<-
#' @export cause
#' @export cause<-
NULL

#' Set a cause and return the input
#' 
#' See \code{\link[assertive.base]{set_cause}}.
#' @name set_cause
#' @export
NULL

# From assertive.base coercion.R

#' Alternative version of is
#' 
#' See \code{\link[assertive.base]{is2}}.
#' @name is2
#' @export
NULL

#' Coerce variable to a different class
#' 
#' See \code{\link[assertive.base]{coerce_to}}.
#' @name coerce_to
#' @export
NULL

# From assertive.base conditions.R

#' Condition classes
#' 
#' See \code{\link[assertive.base]{assertionError}}.
#' @name assertionError
#' @aliases assertionWarning assertionMessage
#' @export assertionError
#' @export assertionWarning
#' @export assertionMessage
NULL

# From assertive.base engine.R

#' Throws an error if a condition isn't met
#' 
#' See \code{\link[assertive.base]{assert_engine}}.
#' @name assert_engine
#' @export
NULL

#' FALSE, with a cause of failure
#' 
#' See \code{\link[assertive.base]{false}}.
#' @name false
#' @export
NULL

#' NA, with a cause of failure
#' 
#' See \code{\link[assertive.base]{na}}.
#' @name na
#' @export
NULL

# From assertive.base utils.R

#' Wrapper to vapply that returns booleans.
#' 
#' See \code{\link[assertive.base]{bapply}}.
#' @name bapply
#' @export
NULL

#' Call a function, and give the result names.
#' 
#' See \code{\link[assertive.base]{call_and_name}}.
#' @name call_and_name
#' @export
NULL

#' Get the dimensions of an object
#' 
#' See \code{\link[assertive.properties]{DIM}}.
#' @name DIM
#' @export
NULL

#' Run code without stopping
#' 
#' See \code{\link[assertive.base]{dont_stop}}.
#' @name dont_stop
#' @export
NULL

#' Get the name of a variable in the parent frame
#' 
#' See \code{\link[assertive.base]{get_name_in_parent}}.
#' @name get_name_in_parent
#' @export
NULL

#' Merge ellipsis args with a list.
#' 
#' See \code{\link[assertive.base]{merge_dots_with_list}}.
#' @name merge_dots_with_list
#' @export
NULL

#' Wrap a string in brackets
#' 
#' See \code{\link[assertive.base]{parenthesize}}.
#' @name parenthesize
#' @aliases parenthesise
#' @export parenthesize
#' @export parenthesise
NULL

#' Print a variable and capture the output
#' 
#' See \code{\link[assertive.base]{print_and_capture}}.
#' @name print_and_capture
#' @export
NULL

#' Safe version of deparse
#' 
#' See \code{\link[assertive.base]{safe_deparse}}.
#' @name safe_deparse
#' @export
NULL

#' Strip all attributes from a variable
#' 
#' See \code{\link[assertive.base]{strip_attributes}}.
#' @name strip_attributes
#' @export
NULL

#' Only use the first element of a vector
#' 
#' See \code{\link[assertive.base]{use_first}}.
#' @name use_first
#' @export
NULL
